EXPORTS
	?NewL@CMessageAddress@@SAPAV1@XZ @ 1 NONAME ; class CMessageAddress * CMessageAddress::NewL(void)
	??0CMessageData@@IAE@XZ @ 2 NONAME ; CMessageData::CMessageData(void)
	??0TSendingCapabilities@@QAE@HHH@Z @ 3 NONAME ; TSendingCapabilities::TSendingCapabilities(int, int, int)
	??0TSendingCapabilities@@QAE@XZ @ 4 NONAME ; TSendingCapabilities::TSendingCapabilities(void)
	??1CMessageAddress@@UAE@XZ @ 5 NONAME ; CMessageAddress::~CMessageAddress(void)
	??1CMessageData@@UAE@XZ @ 6 NONAME ; CMessageData::~CMessageData(void)
	??1CSendUi@@UAE@XZ @ 7 NONAME ; CSendUi::~CSendUi(void)
	??1CSendingService@@UAE@XZ @ 8 NONAME ; CSendingService::~CSendingService(void)
	??1CSendingServiceInfo@@UAE@XZ @ 9 NONAME ; CSendingServiceInfo::~CSendingServiceInfo(void)
	??8TSendingCapabilities@@QBEHABV0@@Z @ 10 NONAME ; int TSendingCapabilities::operator==(class TSendingCapabilities const &) const
	??9TSendingCapabilities@@QBEHABV0@@Z @ 11 NONAME ; int TSendingCapabilities::operator!=(class TSendingCapabilities const &) const
	?AddSendMenuItemL@CSendUi@@QAEXAAVCEikMenuPane@@HHVTSendingCapabilities@@@Z @ 12 NONAME ; void CSendUi::AddSendMenuItemL(class CEikMenuPane &, int, int, class TSendingCapabilities)
	?Address@CMessageAddress@@QBE?BVTPtrC16@@XZ @ 13 NONAME ; class TPtrC16 const CMessageAddress::Address(void) const
	?Alias@CMessageAddress@@QBE?BVTPtrC16@@XZ @ 14 NONAME ; class TPtrC16 const CMessageAddress::Alias(void) const
	?AppendAttachmentHandleL@CMessageData@@QAEXABVRFile@@@Z @ 15 NONAME ; void CMessageData::AppendAttachmentHandleL(class RFile const &)
	?AppendAttachmentL@CMessageData@@QAEXABVTDesC16@@@Z @ 16 NONAME ; void CMessageData::AppendAttachmentL(class TDesC16 const &)
	?AppendBccAddressL@CMessageData@@QAEXABVTDesC16@@0@Z @ 17 NONAME ; void CMessageData::AppendBccAddressL(class TDesC16 const &, class TDesC16 const &)
	?AppendCcAddressL@CMessageData@@QAEXABVTDesC16@@0@Z @ 18 NONAME ; void CMessageData::AppendCcAddressL(class TDesC16 const &, class TDesC16 const &)
	?AppendToAddressL@CMessageData@@QAEXABVTDesC16@@0@Z @ 19 NONAME ; void CMessageData::AppendToAddressL(class TDesC16 const &, class TDesC16 const &)
	?AttachmentArray@CMessageData@@QBEABVCDesC16Array@@XZ @ 20 NONAME ; class CDesC16Array const & CMessageData::AttachmentArray(void) const
	?AttachmentHandleArray@CMessageData@@QBEABV?$RArray@VRFile@@@@XZ @ 21 NONAME ; class RArray<class RFile> const & CMessageData::AttachmentHandleArray(void) const
	?AvailableServicesL@CSendUi@@QAEXAAV?$RPointerArray@VCSendingServiceInfo@@@@VTUid@@@Z @ 22 NONAME ; void CSendUi::AvailableServicesL(class RPointerArray<class CSendingServiceInfo> &, class TUid)
	?BccAddressArray@CMessageData@@QBEABV?$CArrayPtrFlat@VCMessageAddress@@@@XZ @ 23 NONAME ; class CArrayPtrFlat<class CMessageAddress> const & CMessageData::BccAddressArray(void) const
	?BodyText@CMessageData@@QBEPBVCRichText@@XZ @ 24 NONAME ; class CRichText const * CMessageData::BodyText(void) const
	?CanSendBioMessage@CSendUi@@QBEHVTUid@@@Z @ 25 NONAME ; int CSendUi::CanSendBioMessage(class TUid) const
	?CcAddressArray@CMessageData@@QBEABV?$CArrayPtrFlat@VCMessageAddress@@@@XZ @ 26 NONAME ; class CArrayPtrFlat<class CMessageAddress> const & CMessageData::CcAddressArray(void) const
	?ClearAttachmentArray@CMessageData@@QAEXXZ @ 27 NONAME ; void CMessageData::ClearAttachmentArray(void)
	?ConstructL@CMessageData@@IAEXXZ @ 28 NONAME ; void CMessageData::ConstructL(void)
	?CopyLC@CSendingServiceInfo@@QBEPAV1@XZ @ 29 NONAME ; class CSendingServiceInfo * CSendingServiceInfo::CopyLC(void) const
	?CreateAndSendMessageL@CSendUi@@QAEXVTUid@@PBVCMessageData@@0H@Z @ 30 NONAME ; void CSendUi::CreateAndSendMessageL(class TUid, class CMessageData const *, class TUid, int)
	?DataType@CMessageData@@QBE?AVTUid@@XZ @ 31 NONAME ; class TUid CMessageData::DataType(void) const
	?NewL@CMessageData@@SAPAV1@XZ @ 32 NONAME ; class CMessageData * CMessageData::NewL(void)
	?NewL@CSendUi@@SAPAV1@XZ @ 33 NONAME ; class CSendUi * CSendUi::NewL(void)
	?NewL@CSendingService@@SAPAV1@ABVTUid@@AAVCCoeEnv@@AAVCSendUiSingleton@@@Z @ 34 NONAME ; class CSendingService * CSendingService::NewL(class TUid const &, class CCoeEnv &, class CSendUiSingleton &)
	?NewL@CSendingServiceInfo@@SAPAV1@XZ @ 35 NONAME ; class CSendingServiceInfo * CSendingServiceInfo::NewL(void)
	?NewLC@CMessageData@@SAPAV1@XZ @ 36 NONAME ; class CMessageData * CMessageData::NewLC(void)
	?NewLC@CSendUi@@SAPAV1@XZ @ 37 NONAME ; class CSendUi * CSendUi::NewLC(void)
	?NewLC@CSendingServiceInfo@@SAPAV1@XZ @ 38 NONAME ; class CSendingServiceInfo * CSendingServiceInfo::NewLC(void)
	?ServiceAddress@CSendingServiceInfo@@QBE?BVTPtrC16@@XZ @ 39 NONAME ; class TPtrC16 const CSendingServiceInfo::ServiceAddress(void) const
	?ServiceCapabilities@CSendingServiceInfo@@QBE?AVTSendingCapabilities@@XZ @ 40 NONAME ; class TSendingCapabilities CSendingServiceInfo::ServiceCapabilities(void) const
	?ServiceCapabilitiesL@CSendUi@@QAEHVTUid@@AAVTSendingCapabilities@@@Z @ 41 NONAME ; int CSendUi::ServiceCapabilitiesL(class TUid, class TSendingCapabilities &)
	?ServiceId@CSendingServiceInfo@@QBE?AVTUid@@XZ @ 42 NONAME ; class TUid CSendingServiceInfo::ServiceId(void) const
	?ServiceMenuName@CSendingServiceInfo@@QBE?BVTPtrC16@@XZ @ 43 NONAME ; class TPtrC16 const CSendingServiceInfo::ServiceMenuName(void) const
	?ServiceName@CSendingServiceInfo@@QBE?BVTPtrC16@@XZ @ 44 NONAME ; class TPtrC16 const CSendingServiceInfo::ServiceName(void) const
	?ServiceProviderId@CSendingServiceInfo@@QBE?AVTUid@@XZ @ 45 NONAME ; class TUid CSendingServiceInfo::ServiceProviderId(void) const
	?SetAddressL@CMessageAddress@@QAEXABVTDesC16@@@Z @ 46 NONAME ; void CMessageAddress::SetAddressL(class TDesC16 const &)
	?SetAliasL@CMessageAddress@@QAEXABVTDesC16@@@Z @ 47 NONAME ; void CMessageAddress::SetAliasL(class TDesC16 const &)
	?SetBodyTextL@CMessageData@@QAEXPBVCRichText@@@Z @ 48 NONAME ; void CMessageData::SetBodyTextL(class CRichText const *)
	?SetServiceAddressL@CSendingServiceInfo@@QAEXABVTDesC16@@@Z @ 49 NONAME ; void CSendingServiceInfo::SetServiceAddressL(class TDesC16 const &)
	?SetServiceCapabilities@CSendingServiceInfo@@QAEXVTSendingCapabilities@@@Z @ 50 NONAME ; void CSendingServiceInfo::SetServiceCapabilities(class TSendingCapabilities)
	?SetServiceId@CSendingServiceInfo@@QAEXVTUid@@@Z @ 51 NONAME ; void CSendingServiceInfo::SetServiceId(class TUid)
	?SetServiceMenuNameL@CSendingServiceInfo@@QAEXABVTDesC16@@@Z @ 52 NONAME ; void CSendingServiceInfo::SetServiceMenuNameL(class TDesC16 const &)
	?SetServiceNameL@CSendingServiceInfo@@QAEXABVTDesC16@@@Z @ 53 NONAME ; void CSendingServiceInfo::SetServiceNameL(class TDesC16 const &)
	?SetServiceProviderId@CSendingServiceInfo@@QAEXVTUid@@@Z @ 54 NONAME ; void CSendingServiceInfo::SetServiceProviderId(class TUid)
	?SetSubjectL@CMessageData@@QAEXPBVTDesC16@@@Z @ 55 NONAME ; void CMessageData::SetSubjectL(class TDesC16 const *)
	?ShowQueryAndSendL@CSendUi@@QAEXPBVCMessageData@@VTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@VTUid@@HABVTDesC16@@@Z @ 56 NONAME ; void CSendUi::ShowQueryAndSendL(class CMessageData const *, class TSendingCapabilities, class CArrayFix<class TUid> *, class TUid, int, class TDesC16 const &)
	?ShowSendQueryL@CSendUi@@QAE?AVTUid@@PBVCMessageData@@VTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@ABVTDesC16@@@Z @ 57 NONAME ; class TUid CSendUi::ShowSendQueryL(class CMessageData const *, class TSendingCapabilities, class CArrayFix<class TUid> *, class TDesC16 const &)
	?Subject@CMessageData@@QBE?BVTPtrC16@@XZ @ 58 NONAME ; class TPtrC16 const CMessageData::Subject(void) const
	?ToAddressArray@CMessageData@@QBEABV?$CArrayPtrFlat@VCMessageAddress@@@@XZ @ 59 NONAME ; class CArrayPtrFlat<class CMessageAddress> const & CMessageData::ToAddressArray(void) const
	?ValidateServiceL@CSendUi@@QAEHVTUid@@VTSendingCapabilities@@@Z @ 60 NONAME ; int CSendUi::ValidateServiceL(class TUid, class TSendingCapabilities)
	?ClearAddresses@CMessageData@@QAEXXZ @ 61 NONAME ; void CMessageData::ClearAddresses(void)
	?AddTypedMenuItemL@CSendUi@@QAEXW4TSendUiMenuType@1@AAVCEikMenuPane@@HHVTSendingCapabilities@@@Z @ 62 NONAME ; void CSendUi::AddTypedMenuItemL(enum CSendUi::TSendUiMenuType, class CEikMenuPane &, int, int, class TSendingCapabilities)
	?ShowTypedQueryAndSendL@CSendUi@@QAEXW4TSendUiMenuType@1@PBVCMessageData@@VTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@VTUid@@HABVTDesC16@@@Z @ 63 NONAME ; void CSendUi::ShowTypedQueryAndSendL(enum CSendUi::TSendUiMenuType, class CMessageData const *, class TSendingCapabilities, class CArrayFix<class TUid> *, class TUid, int, class TDesC16 const &)
	?ShowTypedQueryL@CSendUi@@QAE?AVTUid@@W4TSendUiMenuType@1@PBVCMessageData@@VTSendingCapabilities@@PAV?$CArrayFix@VTUid@@@@ABVTDesC16@@@Z @ 64 NONAME ; class TUid CSendUi::ShowTypedQueryL(enum CSendUi::TSendUiMenuType, class CMessageData const *, class TSendingCapabilities, class CArrayFix<class TUid> *, class TDesC16 const &)
	?NewLC@CMessageAddress@@SAPAV1@XZ @ 65 NONAME ; class CMessageAddress * CMessageAddress::NewLC(void)
	?TechnologyType@CSendUi@@QBE?AVTUid@@V2@@Z @ 66 NONAME ; class TUid CSendUi::TechnologyType(class TUid) const
	??0CSendingService@@IAE@AAVCCoeEnv@@AAVCSendUiSingleton@@@Z @ 67 NONAME ; CSendingService::CSendingService(class CCoeEnv &, class CSendUiSingleton &)
	?CreateTemplateDataL@CSendingService@@QAEPAVCMessageData@@XZ @ 68 NONAME ABSENT
	?ExternalizeL@CMessageAddress@@QAEXAAVRWriteStream@@@Z @ 69 NONAME ; void CMessageAddress::ExternalizeL(class RWriteStream &)
	?ExternalizeL@CMessageData@@QBEXAAVRWriteStream@@@Z @ 70 NONAME ; void CMessageData::ExternalizeL(class RWriteStream &) const
	?InternalizeL@CMessageAddress@@QAEXAAVRReadStream@@@Z @ 71 NONAME ; void CMessageAddress::InternalizeL(class RReadStream &)
	?InternalizeL@CMessageData@@QAEXAAVRReadStream@@@Z @ 72 NONAME ; void CMessageData::InternalizeL(class RReadStream &)
	?ServiceFeatures@CSendingServiceInfo@@QBEHXZ @ 73 NONAME ; int CSendingServiceInfo::ServiceFeatures(void) const
	?SetServiceFeatures@CSendingServiceInfo@@QAEXH@Z @ 74 NONAME ; void CSendingServiceInfo::SetServiceFeatures(int)
	?SetTechnologyTypeId@CSendingServiceInfo@@QAEXVTUid@@@Z @ 75 NONAME ; void CSendingServiceInfo::SetTechnologyTypeId(class TUid)
	?TechnologyTypeId@CSendingServiceInfo@@QBE?AVTUid@@XZ @ 76 NONAME ; class TUid CSendingServiceInfo::TechnologyTypeId(void) const
	?ClientMtmRegistryL@CSendUiSingleton@@QAEAAVCClientMtmRegistry@@XZ @ 77 NONAME ; class CClientMtmRegistry & CSendUiSingleton::ClientMtmRegistryL(void)
	?MsvSessionL@CSendUiSingleton@@QAEAAVCMsvSession@@XZ @ 78 NONAME ; class CMsvSession & CSendUiSingleton::MsvSessionL(void)
	?MtmUiDataRegistryL@CSendUiSingleton@@QAEAAVCMtmUiDataRegistry@@XZ @ 79 NONAME ; class CMtmUiDataRegistry & CSendUiSingleton::MtmUiDataRegistryL(void)
	?MtmUiRegistryL@CSendUiSingleton@@QAEAAVCMtmUiRegistry@@XZ @ 80 NONAME ; class CMtmUiRegistry & CSendUiSingleton::MtmUiRegistryL(void)
	?NewL@CSendUiSingleton@@SAPAV1@XZ @ 81 NONAME ; class CSendUiSingleton * CSendUiSingleton::NewL(void)
	?OpaqueData@CMessageData@@QBE?BVTPtrC8@@XZ @ 82 NONAME ; class TPtrC8 const CMessageData::OpaqueData(void) const
	?SetOpaqueDataL@CMessageData@@QAEXPBVTDesC8@@VTUid@@@Z @ 83 NONAME ; void CMessageData::SetOpaqueDataL(class TDesC8 const *, class TUid)

